"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Config = void 0;
const tslib_1 = require("tslib");
const autobind_decorator_1 = require("autobind-decorator");
const lodash_1 = require("lodash");
class Config {
    constructor() {
        this.name = '@roots/bud-babel';
        this._plugins = {};
        this._presets = {};
        /**
         * Accessor: enabledPlugins
         */
        this._enabledPlugins = [];
        /**
         * Accessor: enabledPresets
         */
        this._enabledPresets = [];
    }
    get plugins() {
        return this._plugins;
    }
    set plugins(plugins) {
        this._plugins = plugins;
    }
    get presets() {
        return this._presets;
    }
    set presets(presets) {
        this._presets = presets;
    }
    get enabledPlugins() {
        return this._enabledPlugins;
    }
    set enabledPlugins(plugins) {
        this._enabledPlugins = plugins;
    }
    get enabledPresets() {
        return this._enabledPresets;
    }
    set enabledPresets(presets) {
        this._enabledPresets = presets;
    }
    init(app) {
        this.app = app;
        return this;
    }
    normalizeEntry(c) {
        return lodash_1.isString(c)
            ? [c, {}]
            : c;
    }
    setPlugin(plugin) {
        plugin = this.normalizeEntry(plugin);
        this.plugins = Object.assign(Object.assign({}, this.plugins), { [plugin[0]]: plugin });
        return this;
    }
    setPlugins(plugins) {
        plugins.map(this.setPlugin);
        return this;
    }
    setPreset(preset) {
        preset = this.normalizeEntry(preset);
        this.presets = Object.assign(Object.assign({}, this.presets), { [preset[0]]: preset });
        return this;
    }
    setPresets(presets) {
        presets.map(this.setPreset);
        return this;
    }
    unsetPreset(preset) {
        !this.presets[preset]
            ? this.app.error(`${preset} not found`)
            : delete this.presets[preset];
        return this;
    }
    unsetPlugin(plugin) {
        !this.plugins[plugin]
            ? this.app.error(`${plugin} not found`)
            : delete this.plugins[plugin];
        return this;
    }
    setPluginOptions(plugin, options) {
        this.plugins[plugin] = [this.plugins[plugin][0], options];
        return this;
    }
    setPresetOptions(preset, options) {
        this.presets[preset] = [this.presets[preset][0], options];
        return this;
    }
}
tslib_1.__decorate([
    autobind_decorator_1.boundMethod
], Config.prototype, "init", null);
tslib_1.__decorate([
    autobind_decorator_1.boundMethod
], Config.prototype, "normalizeEntry", null);
tslib_1.__decorate([
    autobind_decorator_1.boundMethod
], Config.prototype, "setPlugin", null);
tslib_1.__decorate([
    autobind_decorator_1.boundMethod
], Config.prototype, "setPlugins", null);
tslib_1.__decorate([
    autobind_decorator_1.boundMethod
], Config.prototype, "setPreset", null);
tslib_1.__decorate([
    autobind_decorator_1.boundMethod
], Config.prototype, "setPresets", null);
tslib_1.__decorate([
    autobind_decorator_1.boundMethod
], Config.prototype, "unsetPreset", null);
tslib_1.__decorate([
    autobind_decorator_1.boundMethod
], Config.prototype, "unsetPlugin", null);
tslib_1.__decorate([
    autobind_decorator_1.boundMethod
], Config.prototype, "setPluginOptions", null);
tslib_1.__decorate([
    autobind_decorator_1.boundMethod
], Config.prototype, "setPresetOptions", null);
exports.Config = Config;
//# sourceMappingURL=index.js.map